API reference
=============

.. automodule:: covasim
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   covasim.data

Submodules
----------

.. toctree::
   :maxdepth: 4

   covasim.analysis
   covasim.base
   covasim.defaults
   covasim.immunity
   covasim.interventions
   covasim.misc
   covasim.parameters
   covasim.people
   covasim.plotting
   covasim.population
   covasim.requirements
   covasim.run
   covasim.settings
   covasim.sim
   covasim.untitled35
   covasim.utils
   covasim.version
